@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: tags.ml,v 1.24 2012-05-16 20:00:24 tews Exp $
+ * $Id: tags.ml,v 1.26 2012-05-22 06:16:47 tews Exp $
  * 
  * recursive tagging function
  * 
@@ -38,7 +38,6 @@ let empty_sig_ast = Sig_ast(<:sig_item@no_loc< >>)
 let empty_str_ast = Struct_ast(<:str_item@no_loc< >>)
 
 
-
 (******************************************************************************
  *
  **********************   tagging functions   *********************************
@@ -499,7 +498,12 @@ let rec tag_let_pattern write_tag = function
      * We need everything inside the parenthesis.
      *)
     let wrong_id_loc = translate_loc (Ast.loc_of_ident id) in
-    (* Printf.eprintf "TAGPATT %s\n%!" (Loc.to_string wrong_id_loc); *)
+    (* 
+     * Printf.eprintf "TAGPATT %s %s -> %s\n%!" 
+     *   lid
+     *   (Source_channel.full_string_of_loc (Ast.loc_of_ident id))
+     *   (Source_channel.full_string_of_loc wrong_id_loc);
+     *)
     let loc =
       match Reparse.start_char wrong_id_loc with
 	| '(' -> Reparse.loc_inside_parens wrong_id_loc
@@ -649,9 +653,9 @@ and tag_module_expr write_tag = function
 
   | <:module_expr< $_$ $_$ >>		(* XXX check and probably tag this *)
   | <:module_expr< $id:_$ >>
+  | <:module_expr< (value $exp:_$) >>	(* module expressions *)
     -> ()
 
-  | <:module_expr< (value $exp:_$) >>
   | <:module_expr< $anti:_$ >>
   | <:module_expr< >>
     -> assert false
